Oblivion
Oblivion is a Rust implementation of Oblivion, an end-to-end encryption protocol developed by Noctisynth to secure information. It greatly improves the security, stability, and concurrency of Oblivion based on the Python implementation.
Since the encryption algorithm required in the Oblivion protocol is the ECDHE algorithm, it is based on an efficient and secure key derivation method, which makes it possible to apply it to message dispatching and just-in-time communication.
Re-exports
pub extern crate oblivion_codegen;pub extern crate proc_macro;
Modules
- Oblivion Exceptions
- Oblivion Models
- Oblivion Prelude
- Oblivion Export Types
- Oblivion Utilities
Macros
- Absolute Routing Macros
- Regular routing macro
- Startswith Routing Macros